pub struct ApiCallback<Api>where
Api: Api,{ /* private fields */ }Expand description
A callback that is invoked when an Api::Response
value is received out-of-band (not in reply to a request).
Implementations
Sourceimpl<Api> ApiCallback<Api>where
Api: Api,
impl<Api> ApiCallback<Api>where
Api: Api,
Sourcepub fn new<F, Fut>(callback: F) -> ApiCallback<Api>
pub fn new<F, Fut>(callback: F) -> ApiCallback<Api>
Returns a new instance wrapping the provided function.
Sourcepub fn new_with_context<Context, F, Fut>(
context: Context,
callback: F,
) -> ApiCallback<Api>
pub fn new_with_context<Context, F, Fut>( context: Context, callback: F, ) -> ApiCallback<Api>
Returns a new instance wrapping the provided function, passing a clone
of context as the second parameter. This is just a convenience wrapper
around new() that produces more readable code when needing to access
external information inside of the callback.