pub struct MappedDocuments<D, V>where
V: View,{
pub mappings: Vec<CollectionMap<<<V as View>::Collection as Collection>::PrimaryKey, <V as View>::Key, <V as View>::Value>>,
pub documents: BTreeMap<<<V as View>::Collection as Collection>::PrimaryKey, D>,
}Expand description
A collection of mappings and the associated documents.
Fields
mappings: Vec<CollectionMap<<<V as View>::Collection as Collection>::PrimaryKey, <V as View>::Key, <V as View>::Value>>The collection of mappings.
documents: BTreeMap<<<V as View>::Collection as Collection>::PrimaryKey, D>All associated documents by ID.
Documents can appear in a mapping query multiple times. As a result, they are stored separately to avoid duplication.
Implementations
Sourceimpl<D, V> MappedDocuments<D, V>where
V: View,
impl<D, V> MappedDocuments<D, V>where
V: View,