Struct bonsaidb::keystorage::s3::aws_sdk_s3::operation::list_bucket_analytics_configurations::builders::ListBucketAnalyticsConfigurationsOutputBuilder
#[non_exhaustive]pub struct ListBucketAnalyticsConfigurationsOutputBuilder { /* private fields */ }Expand description
A builder for ListBucketAnalyticsConfigurationsOutput.
Implementations
impl ListBucketAnalyticsConfigurationsOutputBuilder
impl ListBucketAnalyticsConfigurationsOutputBuilder
pub fn is_truncated(
self,
input: bool
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn is_truncated( self, input: bool ) -> ListBucketAnalyticsConfigurationsOutputBuilder
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
pub fn set_is_truncated(
self,
input: Option<bool>
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn set_is_truncated( self, input: Option<bool> ) -> ListBucketAnalyticsConfigurationsOutputBuilder
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
pub fn get_is_truncated(&self) -> &Option<bool>
pub fn get_is_truncated(&self) -> &Option<bool>
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
pub fn continuation_token(
self,
input: impl Into<String>
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn continuation_token( self, input: impl Into<String> ) -> ListBucketAnalyticsConfigurationsOutputBuilder
The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
pub fn set_continuation_token(
self,
input: Option<String>
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn set_continuation_token( self, input: Option<String> ) -> ListBucketAnalyticsConfigurationsOutputBuilder
The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
pub fn get_continuation_token(&self) -> &Option<String>
pub fn get_continuation_token(&self) -> &Option<String>
The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
pub fn next_continuation_token(
self,
input: impl Into<String>
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn next_continuation_token( self, input: impl Into<String> ) -> ListBucketAnalyticsConfigurationsOutputBuilder
NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
pub fn set_next_continuation_token(
self,
input: Option<String>
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn set_next_continuation_token( self, input: Option<String> ) -> ListBucketAnalyticsConfigurationsOutputBuilder
NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
pub fn get_next_continuation_token(&self) -> &Option<String>
pub fn get_next_continuation_token(&self) -> &Option<String>
NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
pub fn analytics_configuration_list(
self,
input: AnalyticsConfiguration
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn analytics_configuration_list( self, input: AnalyticsConfiguration ) -> ListBucketAnalyticsConfigurationsOutputBuilder
Appends an item to analytics_configuration_list.
To override the contents of this collection use set_analytics_configuration_list.
The list of analytics configurations for a bucket.
pub fn set_analytics_configuration_list(
self,
input: Option<Vec<AnalyticsConfiguration>>
) -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn set_analytics_configuration_list( self, input: Option<Vec<AnalyticsConfiguration>> ) -> ListBucketAnalyticsConfigurationsOutputBuilder
The list of analytics configurations for a bucket.
pub fn get_analytics_configuration_list(
&self
) -> &Option<Vec<AnalyticsConfiguration>>
pub fn get_analytics_configuration_list( &self ) -> &Option<Vec<AnalyticsConfiguration>>
The list of analytics configurations for a bucket.
pub fn build(self) -> ListBucketAnalyticsConfigurationsOutput
pub fn build(self) -> ListBucketAnalyticsConfigurationsOutput
Consumes the builder and constructs a ListBucketAnalyticsConfigurationsOutput.