Struct bonsaidb::keystorage::s3::aws_sdk_s3::operation::list_bucket_analytics_configurations::ListBucketAnalyticsConfigurationsOutput
#[non_exhaustive]pub struct ListBucketAnalyticsConfigurationsOutput {
pub is_truncated: bool,
pub continuation_token: Option<String>,
pub next_continuation_token: Option<String>,
pub analytics_configuration_list: Option<Vec<AnalyticsConfiguration>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_truncated: boolIndicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
continuation_token: Option<String>The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
next_continuation_token: Option<String> NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
analytics_configuration_list: Option<Vec<AnalyticsConfiguration>>The list of analytics configurations for a bucket.
Implementations
impl ListBucketAnalyticsConfigurationsOutput
impl ListBucketAnalyticsConfigurationsOutput
pub fn is_truncated(&self) -> bool
pub fn is_truncated(&self) -> bool
Indicates whether the returned list of analytics configurations is complete. A value of true indicates that the list is not complete and the NextContinuationToken will be provided for a subsequent request.
pub fn continuation_token(&self) -> Option<&str>
pub fn continuation_token(&self) -> Option<&str>
The marker that is used as a starting point for this analytics configuration list response. This value is present if it was sent in the request.
pub fn next_continuation_token(&self) -> Option<&str>
pub fn next_continuation_token(&self) -> Option<&str>
NextContinuationToken is sent when isTruncated is true, which indicates that there are more analytics configurations to list. The next request must include this NextContinuationToken. The token is obfuscated and is not a usable value.
pub fn analytics_configuration_list(&self) -> Option<&[AnalyticsConfiguration]>
pub fn analytics_configuration_list(&self) -> Option<&[AnalyticsConfiguration]>
The list of analytics configurations for a bucket.
impl ListBucketAnalyticsConfigurationsOutput
impl ListBucketAnalyticsConfigurationsOutput
pub fn builder() -> ListBucketAnalyticsConfigurationsOutputBuilder
pub fn builder() -> ListBucketAnalyticsConfigurationsOutputBuilder
Creates a new builder-style object to manufacture ListBucketAnalyticsConfigurationsOutput.