Type Alias bonsaidb::keystorage::s3::aws_sdk_s3::operation::list_objects::ListObjectsErrorKind
pub type ListObjectsErrorKind = ListObjectsError;👎Deprecated: Operation
*Error/*ErrorKind types were combined into a single *Error enum. The .kind field on *Error no longer exists and isn’t needed anymore (you can just match on the error directly since it’s an enum now).Expand description
Do not use this.
Operation *Error/*ErrorKind types were combined into a single *Error enum. The .kind field on *Error no longer exists and isn’t needed anymore (you can just match on the error directly since it’s an enum now).
Aliased Type
enum ListObjectsErrorKind {
NoSuchBucket(NoSuchBucket),
Unhandled(Unhandled),
}Variants
NoSuchBucket(NoSuchBucket)
The specified bucket does not exist.
Unhandled(Unhandled)
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).