Struct bonsaidb::keystorage::s3::aws_sdk_s3::operation::put_bucket_cors::builders::PutBucketCorsFluentBuilder
pub struct PutBucketCorsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to PutBucketCors.
Sets the cors configuration for your bucket. If the configuration exists, Amazon S3 replaces it.
To use this operation, you must be allowed to perform the s3:PutBucketCORS action. By default, the bucket owner has this permission and can grant it to others.
You set this configuration on a bucket so that the bucket can service cross-origin requests. For example, you might want to enable a request whose origin is http://www.example.com to access your Amazon S3 bucket at my.example.bucket.com by using the browser's XMLHttpRequest capability.
To enable cross-origin resource sharing (CORS) on a bucket, you add the cors subresource to the bucket. The cors subresource is an XML document in which you configure rules that identify origins and the HTTP methods that can be executed on your bucket. The document is limited to 64 KB in size.
When Amazon S3 receives a cross-origin request (or a pre-flight OPTIONS request) against a bucket, it evaluates the cors configuration on the bucket and uses the first CORSRule rule that matches the incoming browser request to enable a cross-origin request. For a rule to match, the following conditions must be met:
-
The request's
Originheader must matchAllowedOriginelements. -
The request method (for example, GET, PUT, HEAD, and so on) or the
Access-Control-Request-Methodheader in case of a pre-flightOPTIONSrequest must be one of theAllowedMethodelements. -
Every header specified in the
Access-Control-Request-Headersrequest header of a pre-flight request must match anAllowedHeaderelement.
For more information about CORS, go to Enabling Cross-Origin Resource Sharing in the Amazon S3 User Guide.
The following operations are related to PutBucketCors:
Implementations
impl PutBucketCorsFluentBuilder
impl PutBucketCorsFluentBuilder
pub fn as_input(&self) -> &PutBucketCorsInputBuilder
pub fn as_input(&self) -> &PutBucketCorsInputBuilder
Access the PutBucketCors as a reference.
pub async fn send(
self
) -> Result<PutBucketCorsOutput, SdkError<PutBucketCorsError, Response<SdkBody>>>
pub async fn send( self ) -> Result<PutBucketCorsOutput, SdkError<PutBucketCorsError, Response<SdkBody>>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
pub async fn customize(
self
) -> Result<CustomizableOperation<PutBucketCorsOutput, PutBucketCorsError, PutBucketCorsFluentBuilder>, SdkError<PutBucketCorsError>>
pub async fn customize( self ) -> Result<CustomizableOperation<PutBucketCorsOutput, PutBucketCorsError, PutBucketCorsFluentBuilder>, SdkError<PutBucketCorsError>>
Consumes this builder, creating a customizable operation that can be modified before being sent.
pub fn bucket(self, input: impl Into<String>) -> PutBucketCorsFluentBuilder
pub fn bucket(self, input: impl Into<String>) -> PutBucketCorsFluentBuilder
Specifies the bucket impacted by the corsconfiguration.
pub fn set_bucket(self, input: Option<String>) -> PutBucketCorsFluentBuilder
pub fn set_bucket(self, input: Option<String>) -> PutBucketCorsFluentBuilder
Specifies the bucket impacted by the corsconfiguration.
pub fn get_bucket(&self) -> &Option<String>
pub fn get_bucket(&self) -> &Option<String>
Specifies the bucket impacted by the corsconfiguration.
pub fn cors_configuration(
self,
input: CorsConfiguration
) -> PutBucketCorsFluentBuilder
pub fn cors_configuration( self, input: CorsConfiguration ) -> PutBucketCorsFluentBuilder
Describes the cross-origin access configuration for objects in an Amazon S3 bucket. For more information, see Enabling Cross-Origin Resource Sharing in the Amazon S3 User Guide.
pub fn set_cors_configuration(
self,
input: Option<CorsConfiguration>
) -> PutBucketCorsFluentBuilder
pub fn set_cors_configuration( self, input: Option<CorsConfiguration> ) -> PutBucketCorsFluentBuilder
Describes the cross-origin access configuration for objects in an Amazon S3 bucket. For more information, see Enabling Cross-Origin Resource Sharing in the Amazon S3 User Guide.
pub fn get_cors_configuration(&self) -> &Option<CorsConfiguration>
pub fn get_cors_configuration(&self) -> &Option<CorsConfiguration>
Describes the cross-origin access configuration for objects in an Amazon S3 bucket. For more information, see Enabling Cross-Origin Resource Sharing in the Amazon S3 User Guide.
pub fn content_md5(self, input: impl Into<String>) -> PutBucketCorsFluentBuilder
pub fn content_md5(self, input: impl Into<String>) -> PutBucketCorsFluentBuilder
The base64-encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to RFC 1864.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
pub fn set_content_md5(
self,
input: Option<String>
) -> PutBucketCorsFluentBuilder
pub fn set_content_md5( self, input: Option<String> ) -> PutBucketCorsFluentBuilder
The base64-encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to RFC 1864.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
pub fn get_content_md5(&self) -> &Option<String>
pub fn get_content_md5(&self) -> &Option<String>
The base64-encoded 128-bit MD5 digest of the data. This header must be used as a message integrity check to verify that the request body was not corrupted in transit. For more information, go to RFC 1864.
For requests made using the Amazon Web Services Command Line Interface (CLI) or Amazon Web Services SDKs, this field is calculated automatically.
pub fn checksum_algorithm(
self,
input: ChecksumAlgorithm
) -> PutBucketCorsFluentBuilder
pub fn checksum_algorithm( self, input: ChecksumAlgorithm ) -> PutBucketCorsFluentBuilder
Indicates the algorithm used to create the checksum for the object when using the SDK. This header will not provide any additional functionality if not using the SDK. When sending this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
pub fn set_checksum_algorithm(
self,
input: Option<ChecksumAlgorithm>
) -> PutBucketCorsFluentBuilder
pub fn set_checksum_algorithm( self, input: Option<ChecksumAlgorithm> ) -> PutBucketCorsFluentBuilder
Indicates the algorithm used to create the checksum for the object when using the SDK. This header will not provide any additional functionality if not using the SDK. When sending this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
pub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
pub fn get_checksum_algorithm(&self) -> &Option<ChecksumAlgorithm>
Indicates the algorithm used to create the checksum for the object when using the SDK. This header will not provide any additional functionality if not using the SDK. When sending this header, there must be a corresponding x-amz-checksum or x-amz-trailer header sent. Otherwise, Amazon S3 fails the request with the HTTP status code 400 Bad Request. For more information, see Checking object integrity in the Amazon S3 User Guide.
If you provide an individual checksum, Amazon S3 ignores any provided ChecksumAlgorithm parameter.
pub fn expected_bucket_owner(
self,
input: impl Into<String>
) -> PutBucketCorsFluentBuilder
pub fn expected_bucket_owner( self, input: impl Into<String> ) -> PutBucketCorsFluentBuilder
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with the HTTP status code 403 Forbidden (access denied).
pub fn set_expected_bucket_owner(
self,
input: Option<String>
) -> PutBucketCorsFluentBuilder
pub fn set_expected_bucket_owner( self, input: Option<String> ) -> PutBucketCorsFluentBuilder
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with the HTTP status code 403 Forbidden (access denied).
pub fn get_expected_bucket_owner(&self) -> &Option<String>
pub fn get_expected_bucket_owner(&self) -> &Option<String>
The account ID of the expected bucket owner. If the bucket is owned by a different account, the request fails with the HTTP status code 403 Forbidden (access denied).