Struct bonsaidb::keystorage::s3::aws_sdk_s3::types::builders::CsvOutputBuilder
#[non_exhaustive]pub struct CsvOutputBuilder { /* private fields */ }Expand description
A builder for CsvOutput.
Implementations
impl CsvOutputBuilder
impl CsvOutputBuilder
pub fn quote_fields(self, input: QuoteFields) -> CsvOutputBuilder
pub fn quote_fields(self, input: QuoteFields) -> CsvOutputBuilder
Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
pub fn set_quote_fields(self, input: Option<QuoteFields>) -> CsvOutputBuilder
pub fn set_quote_fields(self, input: Option<QuoteFields>) -> CsvOutputBuilder
Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
pub fn get_quote_fields(&self) -> &Option<QuoteFields>
pub fn get_quote_fields(&self) -> &Option<QuoteFields>
Indicates whether to use quotation marks around output fields.
-
ALWAYS: Always use quotation marks for output fields. -
ASNEEDED: Use quotation marks for output fields when needed.
pub fn quote_escape_character(
self,
input: impl Into<String>
) -> CsvOutputBuilder
pub fn quote_escape_character( self, input: impl Into<String> ) -> CsvOutputBuilder
The single character used for escaping the quote character inside an already escaped value.
pub fn set_quote_escape_character(
self,
input: Option<String>
) -> CsvOutputBuilder
pub fn set_quote_escape_character( self, input: Option<String> ) -> CsvOutputBuilder
The single character used for escaping the quote character inside an already escaped value.
pub fn get_quote_escape_character(&self) -> &Option<String>
pub fn get_quote_escape_character(&self) -> &Option<String>
The single character used for escaping the quote character inside an already escaped value.
pub fn record_delimiter(self, input: impl Into<String>) -> CsvOutputBuilder
pub fn record_delimiter(self, input: impl Into<String>) -> CsvOutputBuilder
A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
pub fn set_record_delimiter(self, input: Option<String>) -> CsvOutputBuilder
pub fn set_record_delimiter(self, input: Option<String>) -> CsvOutputBuilder
A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
pub fn get_record_delimiter(&self) -> &Option<String>
pub fn get_record_delimiter(&self) -> &Option<String>
A single character used to separate individual records in the output. Instead of the default value, you can specify an arbitrary delimiter.
pub fn field_delimiter(self, input: impl Into<String>) -> CsvOutputBuilder
pub fn field_delimiter(self, input: impl Into<String>) -> CsvOutputBuilder
The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
pub fn set_field_delimiter(self, input: Option<String>) -> CsvOutputBuilder
pub fn set_field_delimiter(self, input: Option<String>) -> CsvOutputBuilder
The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
pub fn get_field_delimiter(&self) -> &Option<String>
pub fn get_field_delimiter(&self) -> &Option<String>
The value used to separate individual fields in a record. You can specify an arbitrary delimiter.
pub fn quote_character(self, input: impl Into<String>) -> CsvOutputBuilder
pub fn quote_character(self, input: impl Into<String>) -> CsvOutputBuilder
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
pub fn set_quote_character(self, input: Option<String>) -> CsvOutputBuilder
pub fn set_quote_character(self, input: Option<String>) -> CsvOutputBuilder
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".
pub fn get_quote_character(&self) -> &Option<String>
pub fn get_quote_character(&self) -> &Option<String>
A single character used for escaping when the field delimiter is part of the value. For example, if the value is a, b, Amazon S3 wraps this field value in quotation marks, as follows: " a , b ".